<?php

/*
	phpblock_GalleryBlock()

	by Andy Maloney [asmaloney@users.sf.net]

	Inspired by the 'Gallery Last Updated' and 'Gallery Top 10' blocks at
	www.squatty.com by Danny Ledger and others.
*/
function GalleryBlock()
{
	global $GALLERY_BASEDIR;
	global $_CONF;
	global $GB_CONF;
	global $gallery;  
	global $galleryCache;
	global $GALLERY_NO_SESSIONS;
	global $GALLERY_EMBEDDED_INSIDE;
	global $GALLERY_EMBEDDED_INSIDE_TYPE;
	
	// make sure we don't try to start sessions in gallery's init.php
	$GALLERY_NO_SESSIONS = 1;

	require_once( $_CONF['path'] . 'blocks/galleryblock/config.php' );
	require_once( $GALLERY_BASEDIR . 'init.php' );
	require_once( $_CONF['path_html'] . 'galleryblock/galleryblock.php' );


	$galleryCache = new GalleryBlockCache();

	$numAlbums = $galleryCache->albumDB->numAlbums( $gallery->user );

	if ( $numAlbums == 0 )
	{
		if ( $GB_CONF['no_albums_show'] == 1 )
			return $GB_CONF['no_albums_text'];
		
		return;	// do not show the block
	}

	$retval = '';

	if ( $GB_CONF['ht_show'] == 1 )
	{
		$numPhotos = $galleryCache->albumDB->numPhotos( $gallery->user );

		$retval .= str_replace(
						array( '%numphotos', '%numalbums' ),
						array( $numPhotos, $numAlbums ),
						$GB_CONF['ht_text'] );

		$retval .= '<br><br>';
	}

	define( GB_NUM_ALBUMS, count( $galleryCache->albumData ) );

	if ( $GB_CONF['lu_show'] == 1 )
		$retval .= ShowLatestUpdates( $GB_CONF['lu_num_albums'], GB_NUM_ALBUMS );

	if ( ($GB_CONF['lu_show'] == 1) && ($GB_CONF['mv_show'] == 1) )
		$retval .= '<br><br>';

	if ( $GB_CONF['mv_show'] == 1 )
		$retval .= ShowMostViewed( $GB_CONF['mv_num_albums'], GB_NUM_ALBUMS );

	return $retval;
}

// ShowLatestUpdates
function ShowLatestUpdates( $howMany, $numAlbums ) 
{
	global $GB_CONF;  
	global $galleryCache;  


	$galleryCache->NumericDescendingSort( 'last_mod_time' );

	$retval = '<b>' . $GB_CONF['lu_title'] . '</b><hr>';

	$counter = 0;

	foreach ( $galleryCache->albumData as $key => $entry )
	{
		$albumURL = makeAlbumUrl( $entry['name'] );

		if ( $entry['new_update'] && ($GB_CONF['lu_image_path'] != '') )
		{
			$title = "title='" . $entry['title'] . " - " . $entry['num_photos'] . " photos'";
			$width = 'width=' . $GB_CONF['lu_image_width'];
			$height = 'height=' . $GB_CONF['lu_image_height'];

			$retval .= "<img src='" . $GB_CONF['lu_image_path'] . "' align=right $width $height $title>";
		}

		$retval .= '&nbsp;<a href=' . $albumURL . '>' . $entry['title'] . '</a>';

		if ( $GB_CONF['lu_date_format'] != '' )
			$retval .= '<br>&nbsp;&nbsp; ' . $entry['last_mod_str'];

		$counter++;
		
		if ( $counter == $howMany || $counter == $numAlbums )
			break;

		$retval .= '<br>';
	}

	return $retval;
}

// ShowMostViewed
function ShowMostViewed( $howMany, $numAlbums )
{
	global $GB_CONF;  
	global $galleryCache;  


	$galleryCache->NumericDescendingSort( 'clicks' );

	$retval = '<b>' . $GB_CONF['mv_title'] . '</b><hr>';

	$counter = 0;

	foreach ( $galleryCache->albumData as $key => $entry )
	{
		$albumURL = makeAlbumUrl( $entry['name'] );

		$retval .= '&nbsp;<a href=' . $albumURL . '>' . $entry['title'] . '</a>';

		$retval .= str_replace( '%hits', $entry['clicks'], $GB_CONF['mv_text'] );

		$counter++;
		
		if ( $counter == $howMany || $counter == $numAlbums )
			break;

		$retval .= '<br>';
	}

	return $retval;
}

?>
