<?php
/*
	galleryblock.php

	by Andy Maloney [asmaloney@users.sf.net]

	Inspired by the 'Gallery Last Updated' and 'Gallery Top 10' blocks at
	www.squatty.com by Danny Ledger and others.
*/

class GalleryBlockCache
{
	var	$nestedShow;
	var	$nestedParentDepth;
	var	$nestedEllipsis;
	var	$nestedDelimiter;
	var	$cacheFileName;
	var	$cacheDelimiter;
	var	$cacheExpireTime;
	var	$cacheOnlyRoot;
	var	$albumData;
	var	$albumDB;
	var	$dateTimeFormat;
	var	$newUpdateInterval;


	// constructor
	function GalleryBlockCache()
	{
		global $GB_CONF;


		$this->nestedShow = $GB_CONF['nested_show'];
		$this->nestedParentDepth = $GB_CONF['nested_parent_depth'];
		$this->nestedEllipsis = $GB_CONF['nested_ellipsis'];
		$this->nestedDelimiter = $GB_CONF['nested_delimiter'];
		$this->cacheFileName = $GB_CONF['cache_file'];
		$this->cacheDelimiter = $GB_CONF['cache_delimiter'];
		$this->cacheExpireTime = $GB_CONF['cache_expiry'];
		$this->albumDB = new AlbumDB();
		$this->dateTimeFormat = trim( $GB_CONF['lu_date_format'] );
		$this->newUpdateInterval = $GB_CONF['lu_new_update_interval'];

		$this->UpdateCache();
		$this->ReadCache();
	}

	// NumericDescendingSort 
	function NumericDescendingSort( $field )
	{
		if ( !array_key_exists( $field, $this->albumData[0] ) )
		{
			// error
			return false;
		}
		
		foreach ( $this->albumData as $key => $entry )
		{
			$index_array[$key] = $entry[$field];
		}

		array_multisort( $index_array, SORT_DESC, SORT_NUMERIC, $this->albumData );

		return true;
	}

	// UpdateCache
	function UpdateCache()
	{
		// check our cache time
		if ( file_exists( $this->cacheFileName ) )
		{
			$mtime = filemtime( $this->cacheFileName );

			if ( ($mtime != false) && ( (time() - $mtime) < $this->cacheExpireTime ) )
				return;
		}
		
		unset( $this->albumData );

		foreach ( $this->albumDB->albumList as $album )
		{
			$tempTitle = trim( $album->fields['title'] );

			if ( !$album->isRoot() )
			{
				if ( $this->nestedShow != 1 )
					continue;

				if ( $this->nestedParentDepth > 0 )
				{
					$tempAlbum = $album;
					$tempDepth = $this->nestedParentDepth;

					while ( !$tempAlbum->isRoot() )
					{
						if ( $tempDepth == 0 )
						{
							$tempTitle = $this->nestedEllipsis . $tempTitle;
							break;
						}

						$parentAlbum = new Album();
						$parentAlbum->load($tempAlbum->fields['parentAlbumName']);

						$tempTitle = trim( $parentAlbum->fields['title'] ) . $this->nestedDelimiter . $tempTitle;

						$tempDepth--;

						$tempAlbum = $parentAlbum;
					}
				}
			}

			$stripTitle = ereg_replace( "[\r\n]", '', $tempTitle );

			$lastModTime = $album->fields['last_mod_time'];

			$stripLastModStr = ereg_replace( "[\r\n]", '',
					strftime( $this->dateTimeFormat, $album->fields['last_mod_time'] ) );

			if ( (time() - $lastModTime) < $this->newUpdateInterval )
				$newUpdate = 1;
			else
				$newUpdate = 0;

			$this->albumData[] = array(
				'name' => htmlentities( $album->fields['name'] ),
				'title' => htmlentities( $stripTitle ),
				'last_mod_time' => $lastModTime,
				'last_mod_str' => $stripLastModStr,
				'new_update' => $newUpdate,
				'num_photos' => $album->numPhotos(),
				'clicks' => $album->getClicks()
			);
		}

		if ( $fd = fs_fopen( $this->cacheFileName, 'w' ) )
		{
			foreach ( $this->albumData as $entry )
			{
				$imp = implode( $this->cacheDelimiter, $entry );
				fwrite( $fd, "$imp\n" );
			}

			fclose( $fd );

			chmod( $this->cacheFileName, 0600 );
		}
	}

	// ReadCache
	function ReadCache()
	{
		global $gallery;

		if ( !file_exists( $this->cacheFileName ) )
			return false;

		$contents = file( $this->cacheFileName );
		
		unset( $this->albumData );

		// stuff data into array
		foreach ( $contents as $entry )
		{
			list(	$name,
					$title,
					$lastModTime,
					$lastModStr,
					$newUpdate,
					$numPhotos,
					$clicks ) = explode( $this->cacheDelimiter, rtrim( $entry ) );

			$album = $this->albumDB->getAlbumbyName( $name, false );

			if ( ($album != 0) && $gallery->user->canReadAlbum( $album ) )
			{
				$this->albumData[] = array(
					'name' => $name,
					'title' => $title,
					'last_mod_time' => $lastModTime,
					'last_mod_str' => $lastModStr,
					'new_update' => $newUpdate,
					'num_photos' => $numPhotos,
					'clicks' => $clicks
				);
			}
		}

		return true;
	}
}

?>
